;; Generated package description from url-http-ntlm.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "url-http-ntlm" "2.0.5.0.20250314.123040" "NTLM authentication for the url library" '((emacs "24.4") (ntlm "2.1.0")) :commit "8b24c978ecc35f083550f145838f2e8dd9e07e58" :authors '(("Tom Schutzer-Weissmann" . "tom.weissmann@gmail.com")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("comm" "data" "processes" "hypermedia") :url "https://code.google.com/p/url-http-ntlm/")
